==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/table/TableWithPagination.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/table/TableWithPagination.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/pagination-bar', 'frontend-js-react-web$react', '../loading/Loading.es', '../management-toolbar/search/SearchContext.es', './EmptyState.es', './Table.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _paginationBar = require("@frontend-taglib-clay$clayui/pagination-bar");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Loading = require("../loading/Loading.es");

  var _SearchContext = _interopRequireDefault(require("../management-toolbar/search/SearchContext.es"));

  var _EmptyState = require("./EmptyState.es");

  var _Table = _interopRequireDefault(require("./Table.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var TableWithPagination = function TableWithPagination(_ref) {
    var actions = _ref.actions,
        columns = _ref.columns,
        items = _ref.items,
        totalCount = _ref.totalCount;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        page = _useContext2$.page,
        pageSize = _useContext2$.pageSize,
        dispatch = _useContext2[1];

    var deltas = [5, 10, 20, 30, 50, 75].map(function (size) {
      return {
        label: size
      };
    });
    return _react["default"].createElement("div", {
      className: "container-fluid container-fluid-max-xl"
    }, _react["default"].createElement(_Table["default"], {
      actions: actions,
      columns: columns,
      items: items
    }), totalCount > 5 && _react["default"].createElement("div", {
      className: "taglib-search-iterator-page-iterator-bottom"
    }, _react["default"].createElement(_paginationBar.ClayPaginationBarWithBasicItems, {
      activeDelta: pageSize,
      activePage: page,
      deltas: deltas,
      ellipsisBuffer: 3,
      initialActivePage: page,
      initialSelectedDelta: {
        label: pageSize
      },
      onDeltaChange: function onDeltaChange(pageSize) {
        return dispatch({
          pageSize: pageSize,
          type: 'CHANGE_PAGE_SIZE'
        });
      },
      onPageChange: function onPageChange(page) {
        return dispatch({
          page: page,
          type: 'CHANGE_PAGE'
        });
      },
      totalItems: totalCount
    })));
  };

  var _default = (0, _Loading.withLoading)((0, _EmptyState.withEmpty)(TableWithPagination));

  exports["default"] = _default;
  //# sourceMappingURL=TableWithPagination.es.js.map
});
//# sourceMappingURL=TableWithPagination.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/table/TableWithPagination.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/table/TableWithPagination.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/pagination-bar', 'frontend-js-react-web$react', '../loading/Loading.es', '../management-toolbar/search/SearchContext.es', './EmptyState.es', './Table.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _paginationBar = require("@frontend-taglib-clay$clayui/pagination-bar");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Loading = require("../loading/Loading.es");

  var _SearchContext = _interopRequireDefault(require("../management-toolbar/search/SearchContext.es"));

  var _EmptyState = require("./EmptyState.es");

  var _Table = _interopRequireDefault(require("./Table.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var TableWithPagination = function TableWithPagination(_ref) {
    var actions = _ref.actions,
        columns = _ref.columns,
        items = _ref.items,
        totalCount = _ref.totalCount;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        page = _useContext2$.page,
        pageSize = _useContext2$.pageSize,
        dispatch = _useContext2[1];

    var deltas = [5, 10, 20, 30, 50, 75].map(function (size) {
      return {
        label: size
      };
    });
    return _react["default"].createElement("div", {
      className: "container-fluid container-fluid-max-xl"
    }, _react["default"].createElement(_Table["default"], {
      actions: actions,
      columns: columns,
      items: items
    }), totalCount > 5 && _react["default"].createElement("div", {
      className: "taglib-search-iterator-page-iterator-bottom"
    }, _react["default"].createElement(_paginationBar.ClayPaginationBarWithBasicItems, {
      activeDelta: pageSize,
      activePage: page,
      deltas: deltas,
      ellipsisBuffer: 3,
      onDeltaChange: function onDeltaChange(pageSize) {
        return dispatch({
          pageSize: pageSize,
          type: 'CHANGE_PAGE_SIZE'
        });
      },
      onPageChange: function onPageChange(page) {
        return dispatch({
          page: page,
          type: 'CHANGE_PAGE'
        });
      },
      totalItems: totalCount
    })));
  };

  var _default = (0, _Loading.withLoading)((0, _EmptyState.withEmpty)(TableWithPagination));

  exports["default"] = _default;
  //# sourceMappingURL=TableWithPagination.es.js.map
});
//# sourceMappingURL=TableWithPagination.es.js.map
